<?php
namespace Concrete\Package\SimpleAudioPlayer\Block\SimpleAudioPlayer;

use Concrete\Core\Block\BlockController;
use Page;
use Package;
use Core;
use File;
use Concrete\Core\Database\Connection\Connection;

class Controller extends BlockController
{
  protected $btTable = 'btSimpleAudioPlayer';
  protected $btInterfaceWidth = '640';
  protected $btInterfaceHeight = '450';
  protected $btWrapperClass = 'ccm-ui';
  protected $btDefaultSet = 'multimedia';
  protected $pkg = 'simple_audio_player';
  protected $btExportFileColumns = ['fID'];

  protected $fID;
  protected $maxWidth;
  protected $maxWidth2;
  //protected $bID;

  public function getBlockTypeName() {
    return Package::getByHandle($this->pkg)->getPackageName();
  }
  public function getBlockTypeDescription() {
    return Package::getByHandle($this->pkg)->getPackageDescription();
  }

  public function add() {
    $this->augment();
  }
  public function edit() {
    $this->augment();
  }
  public function augment() {
    $audio = null;
    if ( $this->fID > 0 ) {
      $audio = File::getByID($this->fID);
    }
    $this->set('audio', $audio);
    $this->set('templateOptions', array(
      'default' => 'Default',
      'simple' => 'Simple',
      'extra' => 'controlsList="nodownload"'
    ));
    $this->requireAsset('css', 'simpleAudioPlayerForm');

    $this->set('maxWidthForm', $this->makeSlider('maxWidth', $this->maxWidth, '0', '1600'));
    $this->set('maxWidthForm2', $this->makeSlider('maxWidth2', $this->maxWidth2, '0', '1600'));
  }
  public function composer() {
    $this->edit();
  }
  public function save($args) {
    //$args['fID'] = ($data['fID'] != '') ? intval($data['fID']) : 0;
    $db = $this->app->make(Connection::class);
    $args = $args + [
        'fID' => 0,
        'maxWidth' => 0,
        'maxWidth2' => 0
    ];
    $args['fID'] = $args['fID'] != '' ? $args['fID'] : 0;
    //$args['maxWidth'] = $args['maxWidth'] != '' ? $args['maxWidth'] : 0;
    $args['maxWidth'] = (int) $args['maxWidth'] > 0 ? (int) $args['maxWidth'] : 0;
    $args['maxWidth2'] = (int) $args['maxWidth2'] > 0 ? (int) $args['maxWidth2'] : 0;

    parent::save($args);
  }
  public function view() {
    //$file = File::getByID($this->fID);
    $file = $this->getFileObject();
    if ($file) {
      $path = $file->getURL();
      $this->set('audio', $path);
    }
    if ($this->template == 'default') {
      $this->requireAsset('css', 'simpleAudioPlayerDefault');
    } else if ($this->template == 'simple') {
      $this->requireAsset('css', 'simpleAudioPlayerSimple');
    } else if ($this->template == 'extra') {
      $this->requireAsset('css', 'simpleAudioPlayerExtra');
    }
    $this->renderStyles($this->template);
  }
  public function renderStyles($template) {
    ob_start();
    if ($template == 'simple') {
      echo '.ccm-page #simple-audio-player-container-' . $this->bID . ' .simple-audio-player-simple {' .
        'background-color:' . $this->backgroundColor . ';' .
      '}';
      echo '.ccm-page #simple-audio-player-container-' . $this->bID . ' .simple-audio-player-simple svg {' .
        'fill:' . $this->color . ';' .
      '}';
    } else if ($template == 'default' || $template == 'extra') {
      if ($this->maxWidth) {
        echo '.ccm-page #simple-audio-player-container-' . $this->bID . '.simple-audio-player-template-default .simple-audio-player-audio {' .
          'max-width:' . $this->maxWidth . 'px;' .
        '}';
      }
      if ($this->maxWidth2) {
        echo '.ccm-page #simple-audio-player-container-' . $this->bID . '.simple-audio-player-template-extra .simple-audio-player-audio {' .
          'max-width:' . $this->maxWidth2 . 'px;' .
        '}';
      }
    }
    $styles = ob_get_contents();
    ob_end_clean();
    $this->addHeaderItem('<style class="simple-audio-player-stylesheet">' . $styles . '</style>');
  }
  public function makeSlider($name, $value, $min, $max ,$unit = 'px') {
    ob_start();
    if (!$value) {
      $value = 0;
    }
    echo '<div class="ccm-input-text range-slider">';
    echo '<input type="range" id="' . $name . '" class="form-control range-slider-input" name="' . $name . '" value="' .$value . '" min="' . $min . '" max="' .$max . '" step="1">';
    echo '<div class="range-slider-display">';
    echo '<span class="range-slider-value">';
    echo $value;
    echo '</span>'; // end range-slider-value
    echo $unit;
    echo '</div>'; // end range-slider-display
    echo '</div>';
    $slider = ob_get_contents();
    ob_end_clean();
    return $slider;
  }
  public function getFileObject()
  {
    return File::getByID($this->getFileID());
  }
  public function getFileID()
  {
    return isset($this->record->fID) ? $this->record->fID : (isset($this->fID) ? $this->fID : null);
  }
}
